@@ -50,6 +50,7 @@ __all__ = [
     "DataJointError",
     "key",
     "key_hash",
+    "logger",
 ]
 
 from .logging import logger
@@ -69,7 +70,6 @@ from .hash import key_hash
 from .attribute_adapter import AttributeAdapter
 from . import errors
 from .errors import DataJointError
-from .migrate import migrate_dj011_external_blob_storage_to_dj012
 
 ERD = Di = Diagram  # Aliases for Diagram
 schema = Schema  # Aliases for Schema
