@@ -12,7 +12,7 @@ TRUNCATION_APPENDIX = "...truncated"
 
 class JobTable(Table):
     """
-    A base relation with no definition. Allows reserving jobs
+    A base table with no definition. Allows reserving jobs
     """
 
     def __init__(self, conn, database):
@@ -65,6 +65,7 @@ class JobTable(Table):
         """
         Reserve a job for computation.  When a job is reserved, the job table contains an entry for the
         job key, identified by its hash. When jobs are completed, the entry is removed.
+
         :param table_name: `database`.`table_name`
         :param key: the dict of the job's primary key
         :return: True if reserved job successfully. False = the jobs is already taken
@@ -86,9 +87,41 @@ class JobTable(Table):
             return False
         return True
 
+    def ignore(self, table_name, key):
+        """
+        Set a job to be ignored for computation.  When a job is ignored, the job table contains an entry for the
+        job key, identified by its hash, with status "ignore".
+
+        Args:
+        table_name:
+            Table name (str) - `database`.`table_name`
+        key:
+            The dict of the job's primary key
+
+        Returns:
+            True if ignore job successfully. False = the jobs is already taken
+        """
+        job = dict(
+            table_name=table_name,
+            key_hash=key_hash(key),
+            status="ignore",
+            host=platform.node(),
+            pid=os.getpid(),
+            connection_id=self.connection.connection_id,
+            key=key,
+            user=self._user,
+        )
+        try:
+            with config(enable_python_native_blobs=True):
+                self.insert1(job, ignore_extra_fields=True)
+        except DuplicateError:
+            return False
+        return True
+
     def complete(self, table_name, key):
         """
         Log a completed job.  When a job is completed, its reservation entry is deleted.
+
         :param table_name: `database`.`table_name`
         :param key: the dict of the job's primary key
         """
@@ -99,6 +132,7 @@ class JobTable(Table):
         """
         Log an error message.  The job reservation is replaced with an error entry.
         if an error occurs, leave an entry describing the problem
+
         :param table_name: `database`.`table_name`
         :param key: the dict of the job's primary key
         :param error_message: string error message
