@@ -56,20 +56,20 @@ def repr_html(query_expression):
 
     css = """
     <style type="text/css">
-        .Relation{
+        .Table{
             border-collapse:collapse;
         }
-        .Relation th{
+        .Table th{
             background: #A0A0A0; color: #ffffff; padding:4px; border:#f0e0e0 1px solid;
             font-weight: normal; font-family: monospace; font-size: 100%;
         }
-        .Relation td{
+        .Table td{
             padding:4px; border:#f0e0e0 1px solid; font-size:100%;
         }
-        .Relation tr:nth-child(odd){
+        .Table tr:nth-child(odd){
             background: #ffffff;
         }
-        .Relation tr:nth-child(even){
+        .Table tr:nth-child(even){
             background: #f3f1ff;
         }
         /* Tooltip container */
@@ -111,7 +111,7 @@ def repr_html(query_expression):
     {css}
     {title}
         <div style="max-height:1000px;max-width:1500px;overflow:auto;">
-        <table border="1" class="Relation">
+        <table border="1" class="Table">
             <thead> <tr style="text-align: right;"> <th> {head} </th> </tr> </thead>
             <tbody> <tr> {body} </tr> </tbody>
         </table>
