@@ -6,7 +6,9 @@ import numpy as np
 import pandas
 import logging
 import uuid
+import csv
 import re
+import json
 from pathlib import Path
 from .settings import config
 from .declare import declare, alter
@@ -22,6 +24,7 @@ from .errors import (
     UnknownAttributeError,
     IntegrityError,
 )
+from typing import Union
 from .version import __version__ as version
 
 logger = logging.getLogger(__name__.split(".")[0])
@@ -116,11 +119,11 @@ class Table(QueryExpression):
             frame = inspect.currentframe().f_back
             context = dict(frame.f_globals, **frame.f_locals)
             del frame
-        old_definition = self.describe(context=context, printout=False)
+        old_definition = self.describe(context=context)
         sql, external_stores = alter(self.definition, old_definition, context)
         if not sql:
             if prompt:
-                print("Nothing to alter.")
+                logger.warn("Nothing to alter.")
         else:
             sql = "ALTER TABLE {tab}\n\t".format(
                 tab=self.full_table_name
@@ -140,7 +143,7 @@ class Table(QueryExpression):
                         table_info=self.heading.table_info
                     )
                     if prompt:
-                        print("Table altered")
+                        logger.info("Table altered")
                     self._log("Altered " + self.full_table_name)
 
     def from_clause(self):
@@ -344,17 +347,20 @@ class Table(QueryExpression):
         """
         Insert a collection of rows.
 
-        :param rows: An iterable where an element is a numpy record, a dict-like object, a
-            pandas.DataFrame, a sequence, or a query expression with the same heading as self.
+        :param rows: Either (a) an iterable where an element is a numpy record, a
+            dict-like object, a pandas.DataFrame, a sequence, or a query expression with
+            the same heading as self, or (b) a pathlib.Path object specifying a path
+            relative to the current directory with a CSV file, the contents of which
+            will be inserted.
         :param replace: If True, replaces the existing tuple.
         :param skip_duplicates: If True, silently skip duplicate inserts.
         :param ignore_extra_fields: If False, fields that are not in the heading raise error.
-        :param allow_direct_insert: applies only in auto-populated tables. If False (default),
-            insert are allowed only from inside the make callback.
+        :param allow_direct_insert: Only applies in auto-populated tables. If False (default),
+            insert may only be called from inside the make callback.
 
         Example:
 
-            >>> relation.insert([
+            >>> Table.insert([
             >>>     dict(subject_id=7, species="mouse", date_of_birth="2014-09-01"),
             >>>     dict(subject_id=8, species="mouse", date_of_birth="2014-09-02")])
         """
@@ -365,6 +371,10 @@ class Table(QueryExpression):
                 drop=len(rows.index.names) == 1 and not rows.index.names[0]
             ).to_records(index=False)
 
+        if isinstance(rows, Path):
+            with open(rows, newline="") as data_file:
+                rows = list(csv.DictReader(data_file, delimiter=","))
+
         # prohibit direct inserts into auto-populated tables
         if not allow_direct_insert and not getattr(self, "_allow_insert", True):
             raise DataJointError(
@@ -459,15 +469,30 @@ class Table(QueryExpression):
         self._log(query[:255])
         return count
 
-    def delete(self, transaction=True, safemode=None, force_parts=False):
+    def delete(
+        self,
+        transaction: bool = True,
+        safemode: Union[bool, None] = None,
+        force_parts: bool = False,
+    ) -> int:
         """
         Deletes the contents of the table and its dependent tables, recursively.
 
-        :param transaction: if True, use the entire delete becomes an atomic transaction. This is the default and
-                            recommended behavior. Set to False if this delete is nested within another transaction.
-        :param safemode: If True, prohibit nested transactions and prompt to confirm. Default is dj.config['safemode'].
-        :param force_parts: Delete from parts even when not deleting from their masters.
-        :return: number of deleted rows (excluding those from dependent tables)
+        Args:
+            transaction: If `True`, use of the entire delete becomes an atomic transaction.
+                This is the default and recommended behavior. Set to `False` if this delete is
+                nested within another transaction.
+            safemode: If `True`, prohibit nested transactions and prompt to confirm. Default
+                is `dj.config['safemode']`.
+            force_parts: Delete from parts even when not deleting from their masters.
+
+        Returns:
+            Number of deleted rows (excluding those from dependent tables).
+
+        Raises:
+            DataJointError: Delete exceeds maximum number of delete attempts.
+            DataJointError: When deleting within an existing transaction.
+            DataJointError: Deleting a part table before its master.
         """
         deleted = set()
 
@@ -579,7 +604,7 @@ class Table(QueryExpression):
         # Confirm and commit
         if delete_count == 0:
             if safemode:
-                print("Nothing to delete.")
+                logger.warn("Nothing to delete.")
             if transaction:
                 self.connection.cancel_transaction()
         else:
@@ -587,18 +612,17 @@ class Table(QueryExpression):
                 if transaction:
                     self.connection.commit_transaction()
                 if safemode:
-                    print("Deletes committed.")
+                    logger.info("Deletes committed.")
             else:
                 if transaction:
                     self.connection.cancel_transaction()
                 if safemode:
-                    print("Deletes cancelled")
+                    logger.warn("Deletes cancelled")
         return delete_count
 
     def drop_quick(self):
         """
-        Drops the table associated with this relation without cascading and without user prompt.
-        If the table has any dependent table(s), this call will fail with an error.
+        Drops the table without cascading to dependent tables and without user prompt.
         """
         if self.is_declared:
             query = "DROP TABLE %s" % self.full_table_name
@@ -639,12 +663,14 @@ class Table(QueryExpression):
 
         if config["safemode"]:
             for table in tables:
-                print(table, "(%d tuples)" % len(FreeTable(self.connection, table)))
+                logger.info(
+                    table + " (%d tuples)" % len(FreeTable(self.connection, table))
+                )
             do_drop = user_choice("Proceed?", default="no") == "yes"
         if do_drop:
             for table in reversed(tables):
                 FreeTable(self.connection, table).drop_quick()
-            print("Tables dropped.  Restart kernel.")
+            logger.info("Tables dropped. Restart kernel.")
 
     @property
     def size_on_disk(self):
@@ -664,9 +690,9 @@ class Table(QueryExpression):
             "show_definition is deprecated. Use the describe method instead."
         )
 
-    def describe(self, context=None, printout=True):
+    def describe(self, context=None, printout=False):
         """
-        :return:  the definition string for the relation using DataJoint DDL.
+        :return:  the definition string for the query using DataJoint DDL.
         """
         if context is None:
             frame = inspect.currentframe().f_back
@@ -745,61 +771,9 @@ class Table(QueryExpression):
                 unique="UNIQUE " if v["unique"] else "", attrs=", ".join(k)
             )
         if printout:
-            print(definition)
+            logger.info("\n" + definition)
         return definition
 
-    def _update(self, attrname, value=None):
-        """
-        This is a deprecated function to be removed in datajoint 0.14.
-        Use ``.update1`` instead.
-
-        Updates a field in one existing tuple. self must be restricted to exactly one entry.
-        In DataJoint the principal way of updating data is to delete and re-insert the
-        entire record and updates are reserved for corrective actions.
-        This is because referential integrity is observed on the level of entire
-        records rather than individual attributes.
-
-        Safety constraints:
-           1. self must be restricted to exactly one tuple
-           2. the update attribute must not be in primary key
-
-        Example:
-        >>> (v2p.Mice() & key)._update('mouse_dob', '2011-01-01')
-        >>> (v2p.Mice() & key)._update( 'lens')   # set the value to NULL
-        """
-        logger.warning(
-            "`_update` is a deprecated function to be removed in datajoint 0.14. "
-            "Use `.update1` instead."
-        )
-        if len(self) != 1:
-            raise DataJointError("Update is only allowed on one tuple at a time")
-        if attrname not in self.heading:
-            raise DataJointError("Invalid attribute name")
-        if attrname in self.heading.primary_key:
-            raise DataJointError("Cannot update a key value.")
-
-        attr = self.heading[attrname]
-
-        if attr.is_blob:
-            value = blob.pack(value)
-            placeholder = "%s"
-        elif attr.numeric:
-            if value is None or np.isnan(float(value)):  # nans are turned into NULLs
-                placeholder = "NULL"
-                value = None
-            else:
-                placeholder = "%s"
-                value = str(int(value) if isinstance(value, bool) else value)
-        else:
-            placeholder = "%s" if value is not None else "NULL"
-        command = "UPDATE {full_table_name} SET `{attrname}`={placeholder} {where_clause}".format(
-            full_table_name=self.from_clause(),
-            attrname=attrname,
-            placeholder=placeholder,
-            where_clause=self.where_clause(),
-        )
-        self.connection.query(command, args=(value,) if value is not None else ())
-
     # --- private helper functions ----
     def __make_placeholder(self, name, value, ignore_extra_fields=False):
         """
@@ -858,6 +832,8 @@ class Table(QueryExpression):
                 value = self.external[attr.store].upload_filepath(value).bytes
             elif attr.numeric:
                 value = str(int(value) if isinstance(value, bool) else value)
+            elif attr.json:
+                value = json.dumps(value)
         return name, placeholder, value
 
     def __make_row_to_insert(self, row, field_list, ignore_extra_fields):
@@ -989,7 +965,7 @@ def lookup_class_name(name, context, depth=3):
 
 class FreeTable(Table):
     """
-    A base relation without a dedicated class. Each instance is associated with a table
+    A base table without a dedicated class. Each instance is associated with a table
     specified by full_table_name.
 
     :param conn:  a dj.Connection object
